 
/***************************************************************************************
 * CalibrateAzimuthDrive -  This procedure calibrates and aligns the Azimuth Stepper Motor 
 * drive. It does this by finding 0 degrees Azimuth  (backside of  Azimuth limit switch) and counts the 
 * number of steps counterclockwise until the Azimuth Limit Switch is triggered.
 * It returns a TRUE if successful. 
 ***************************************************************************************/
int CalibrateAzimuthDrive (void)
{ 

int TotalNumberAzimuthSteps = 0;   // Total number of steps corresponding to 360 degrees 

    PrintToScreen("trace 1: Start of Azimuth Drive Calibration \r");
    //PrintToScreen("1. Position the Sunbot platform clockwise to 0 degrees Azimuth (backside of  Azimuth limit switch).  \r");

    // Move The Azimuth Stepper Motors CounterClockwise 1 step at a time while checking the CCW Limit Switch state.    
    //while(GetDigitalInput(AzimuthCWLimit) == 1)
    while(GetDigitalInput(AzimuthCCWLimit) == 1)
    {
       	TotalNumberAzimuthSteps++;
       	//PrintToScreen("2. TotalNumberAzimuthSteps =  %d \r", TotalNumberAzimuthSteps);
 	   	MoveStepper(AZIMUTH_STEPPER_MOTOR, CLOCKWISE, 1);
       	//Wait(100);

    	// Get the latest encoder reading from the Azimutn Drive
       	AzimuthEncoderCounts = - GetQuadEncoder(AzimuthEncoderInt,  AzimuthEncoderInput);
    	PrintToScreen("AZ Encoder Counts =  %ld\r", AzimuthEncoderCounts);
     }

    PrintToScreen("2. TotalNumberAzimuthSteps =  %d \r", TotalNumberAzimuthSteps);
    PrintToScreen("   AzimuthEncoderCounts    =  %ld \r", AzimuthEncoderCounts);

    PrintToScreen("trace 3: End of Azimuth Drive Calibration \r");
    return TRUE;
}

/***************************************************************************************
 * CalibrateElevaionDrive -  This procedure calibrates and aligns the Elevaion Stepper Motor 
 * drive. It does this by finding 0 degrees Elevation (backside of Elevation limit switch) and counts the 
 * number of steps counterclockwise until the Elevation Limit Switch is triggered.
 ***************************************************************************************/
int CalibrateElevationDrive (void)
{
 int TotalNumberElevationSteps = 0;   // Total number of steps corresponding to 360 degrees 

   PrintToScreen("trace 1: Start of Elevation Drive Calibration \r");
    //PrintToScreen("1. Position the solar panel platform clockwise to 0 degrees  Elevation (backside of Elevation limit switch).  \r");


    // Move The Elevation Stepper Motors Clockwise 1 step at a time while checking the CW Limit Switch state.    
    //while(GetDigitalInput(ElevationCWLimit) == 1)
    while(GetDigitalInput(ElevationCCWLimit) == 1)
    {
        TotalNumberElevationSteps++;    // Total number of steps corresponding to +/-90 degrees Elevation
        //PrintToScreen("2. TotalNumberElevationSteps =  %d \r", TotalNumberElevationSteps);

  	   	MoveStepper(ELEVATION_STEPPER_MOTOR, CLOCKWISE, 1);
       	//Wait(100);

     	// Get the latest encoder reading from the Elevation Drive
       	ElevationEncoderCounts = GetQuadEncoder(ElevationEncoderInt, ElevationEncoderInput);
    	PrintToScreen("El Encoder Counts =  %ld\r", ElevationEncoderCounts);
        //Wait(100);
    }
    PrintToScreen("2. TotalNumberElevationSteps =  %d \r", TotalNumberElevationSteps);
    PrintToScreen("   ElevationEncoderCounts    =  %ld \r", AzimuthEncoderCounts);

    PrintToScreen("trace 3: End of Elevation Drive Calibration \r");

    return TRUE;
}
 